==========
Exceptions
==========

Various exception classes that can be raised by ``django_mysql`` code. They can
imported from the ``django_mysql.exceptions`` module.

.. automodule:: django_mysql.exceptions
    :members:
